@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.0;
 
-our $VERSION = '1.756';
+our $VERSION = '1.757';
 
 use Exporter qw( import );
 
@@ -255,8 +255,7 @@ sub table_char_width { [
 [  0x109d,   0x109d, 0],
 [  0x109e,   0x10ff, 1],
 [  0x1100,   0x115f, 2],
-[  0x1160,   0x11ff, 0],
-[  0x1200,   0x135c, 1],
+[  0x1160,   0x135c, 1],
 [  0x135d,   0x135f, 0],
 [  0x1360,   0x1711, 1],
 [  0x1712,   0x1714, 0],
@@ -854,8 +853,8 @@ sub table_char_width { [
 [ 0x1f18e,  0x1f18e, 2],
 [ 0x1f18f,  0x1f190, 1],
 [ 0x1f191,  0x1f19a, 2],
-[ 0x1f19b,  0x1f1ff, 1],
-[ 0x1f200,  0x1f202, 2],
+[ 0x1f19b,  0x1f1e5, 1],
+[ 0x1f1e6,  0x1f202, 2],
 [ 0x1f203,  0x1f20f, 1],
 [ 0x1f210,  0x1f23b, 2],
 [ 0x1f23c,  0x1f23f, 1],
